aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/rosa/rosa.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/rosa/rosa.go')
-rw-r--r--internal/rosa/rosa.go38
1 files changed, 19 insertions, 19 deletions
diff --git a/internal/rosa/rosa.go b/internal/rosa/rosa.go
index 9e54fae9..c92928f5 100644
--- a/internal/rosa/rosa.go
+++ b/internal/rosa/rosa.go
@@ -82,11 +82,11 @@ func earlyLDFLAGS(static bool) string {
return s
}
// earlyCFLAGS is reference CFLAGS for the stage3 toolchain.
const earlyCFLAGS = "-Qunused-arguments " +
"-isystem/system/include"
// earlyCXXFLAGS returns reference CXXFLAGS for the stage3 toolchain
// corresponding to [runtime.GOARCH].
func earlyCXXFLAGS() string {
return "--start-no-unused-arguments " +
@@ -105,12 +105,12 @@ const (
// binary distribution. This is for decompressing unsupported formats.
toolchainBusybox Toolchain = iota
- // toolchainStage3 denotes the Gentoo stage3 toolchain. Special care must be
- // taken to compile correctly against this toolchain.
- toolchainStage3
+ // toolchainStage0 denotes the stage0 toolchain. Special care must be taken
+ // to compile correctly against this toolchain.
+ toolchainStage0
// toolchainIntermediate denotes the intermediate toolchain compiled against
// toolchainStage3. This toolchain should be functionally identical to [Std]
// and is used to bootstrap [Std].
toolchainIntermediate
@@ -122,19 +122,19 @@ const (
_toolchainEnd
)
-// stage3Concat concatenates s and values. If the current toolchain is
-// toolchainStage3, stage3Concat returns s as is.
-func stage3Concat[S ~[]E, E any](t Toolchain, s S, values ...E) S {
- if t == toolchainStage3 {
+// stage0Concat concatenates s and values. If the current toolchain is
+// toolchainStage0, stage0Concat returns s as is.
+func stage0Concat[S ~[]E, E any](t Toolchain, s S, values ...E) S {
+ if t == toolchainStage0 {
return s
}
return slices.Concat(s, values)
}
-// stage3ExclConcat concatenates s and values. If the current toolchain is not
-// toolchainStage3, stage3ExclConcat returns s as is.
-func stage3ExclConcat[S ~[]E, E any](t Toolchain, s S, values ...E) S {
- if t == toolchainStage3 {
+// stage0ExclConcat concatenates s and values. If the current toolchain is not
+// toolchainStage0, stage0ExclConcat returns s as is.
+func stage0ExclConcat[S ~[]E, E any](t Toolchain, s S, values ...E) S {
+ if t == toolchainStage0 {
return slices.Concat(s, values)
}
return s
@@ -208,7 +208,7 @@ func (t Toolchain) New(
args[0] = "hush"
env = fixupEnviron(env, nil, "/system/bin")
- case toolchainStage3:
+ case toolchainStage0:
name += "-boot"
var seed string
switch runtime.GOARCH {
@@ -224,11 +224,11 @@ func (t Toolchain) New(
args[0] = "bash"
support = slices.Concat([]pkg.Artifact{
cureEtc{},
- toolchainBusybox.New("stage3", 0, nil, nil, nil, `
-tar -C /work -xf /usr/src/stage3.tar.xz
+ toolchainBusybox.New("stage0", 0, nil, nil, nil, `
+tar -C /work -xf /usr/src/stage0.tar.xz
rm -rf /work/dev/ /work/proc/
ln -vs ../usr/bin /work/bin
-`, pkg.Path(AbsUsrSrc.Append("stage3.tar.xz"), false,
+`, pkg.Path(AbsUsrSrc.Append("stage0.tar.xz"), false,
pkg.NewHTTPGet(
nil, "https://basement.gensokyo.uk/seed/"+seed,
mustDecode(seed),
@@ -328,7 +328,7 @@ cat /usr/src/` + name + `-patches/* | \
`
aname += "-patched"
}
- return t.New(aname, 0, stage3Concat(t, []pkg.Artifact{},
+ return t.New(aname, 0, stage0Concat(t, []pkg.Artifact{},
t.Load(Patch),
), nil, nil, script, paths...)
}
@@ -82,11 +82,11 @@ func earlyLDFLAGS(static bool) string {
return s
}
-// earlyCFLAGS is reference CFLAGS for the stage3 toolchain.
+// earlyCFLAGS is reference CFLAGS for the stage0 toolchain.
const earlyCFLAGS = "-Qunused-arguments " +
"-isystem/system/include"
@@ -82,11 +82,11 @@ func earlyLDFLAGS(static bool) string {
const earlyCFLAGS = "-Qunused-arguments " +
"-isystem/system/include"
-// earlyCXXFLAGS returns reference CXXFLAGS for the stage3 toolchain
+// earlyCXXFLAGS returns reference CXXFLAGS for the stage0 toolchain
// corresponding to [runtime.GOARCH].
func earlyCXXFLAGS() string {
@@ -105,12 +105,12 @@ const (
// toolchainIntermediate denotes the intermediate toolchain compiled against
- // toolchainStage3. This toolchain should be functionally identical to [Std]
+ // toolchainStage0. This toolchain should be functionally identical to [Std]
// and is used to bootstrap [Std].
toolchainIntermediate